@@ -32,6 +32,10 @@ class HeadlessChromeDriver(object):
                         '--no-sandbox',
                         '--headless',
                         '--disable-gpu',
+                        '--disable-web-security',
+                        '-–allow-file-access-from-files',
+                        '--run-all-compositor-stages-before-draw',
+                        '--virtual-time-budget=10000',
                         '--dump-dom',
                         temp.name], stdout=PIPE) as chrome:
                 return chrome.stdout.read().decode('utf-8')
