@@ -31,6 +31,9 @@ class Generator(object):
         self._nav = None
         self._head = None
 
+        self._scraped_scripts = []
+        self._mixed_script = ''
+
     def on_nav(self, nav):
         """ on_nav """
         self._nav = nav
@@ -78,10 +81,12 @@ class Generator(object):
                 a.decompose()
             self._fix_missing_id_for_h1(article, page)
             setattr(page, 'pdf-article', article)
+            self._scrap_scripts(soup)
         else:
             self.logger.warning(f'Missing article: [{page.title}]({page.url})')
 
-        return self._theme.inject_link(output_content, pdf_path)
+        return self._options.hook.inject_link(
+            output_content, pdf_path, page, self._theme)
 
     def on_post_build(self, config, output_path):
         if self._head:
@@ -120,6 +125,8 @@ class Generator(object):
         self._normalize_link_anchors(soup)
         html_string = self._render_js(soup)
 
+        html_string = self._options.hook.pre_pdf_render(html_string)
+
         if self._options.debug_html:
             print(f'{html_string}')
 
@@ -345,10 +352,49 @@ class Generator(object):
             fix_twemoji(soup, self._options.logger)
             return str(soup)
 
+        soup = self._options.hook.pre_js_render(soup)
+
         scripts = self._theme.get_script_sources()
         if len(scripts) > 0:
             body = soup.find('body')
             if body:
+                for script in self._scraped_scripts:
+                    body.append(script)
+                if len(self._mixed_script) > 0:
+                    tag = soup.new_tag('script')
+                    tag.text = self._mixed_script
+                    body.append(tag)
                 for src in scripts:
                     body.append(soup.new_tag('script', src=f'file://{src}'))
+
         return self._options.js_renderer.render(str(soup))
+
+    def _scrap_scripts(self, soup):
+        if not self._options.js_renderer:
+            return
+
+        # CAUTION:
+        # It does not consider cases where the tag contains both src and text.
+
+        scripts = soup.select('body>script')
+        if not scripts:
+            return
+
+        def exists_src(src):
+            for script in self._scraped_scripts:
+                if src == script['src']:
+                    return True
+            return False
+
+        for script in scripts:
+            if script.has_attr('src'):
+                src = script['src']
+                if (not src
+                    or not re.match(r'^http?s://', src)
+                        or exists_src(src)):
+                    continue
+                self._scraped_scripts.append(script)
+            else:
+                text = script.get_text()
+                if text:
+                    self._mixed_script += ';' + text
